@@ -1,4 +1,5 @@
 """DisplayLib
+----------------
 
 Submodules:
 - template
@@ -6,12 +7,13 @@ Submodules:
 - pygame
 """
 
-__version__ = "0.0.4"
+__version__ = "0.0.6"
 __author__ = "FloatingInt"
-__all__ = [
+__all__ = [ # when using default mode
     "Vec2",
     "overload",
     "OverloadUnmatched",
+    "graphme",
     "ASCIINode",
     "ASCIIEngine",
     "ASCIICamera",
@@ -19,14 +21,17 @@ __all__ = [
     "ASCIIScreen",
     "ASCIIImage",
     "ASCIIClient",
-    "Clock"
+    "ASCIILabel"
 ]
 
-# utility
+# -- util
 from .overload import overload, OverloadUnmatched
 from .math import Vec2
-# default module
+# -- imports
 from .ascii import (
+    # -- util
+    grapheme as graphme,
+    # -- core
     Node as ASCIINode,
     Engine as ASCIIEngine,
     Camera as ASCIICamera,
@@ -38,5 +43,7 @@ from .ascii import (
     Animation as Animation,
     EmptyAnimation as EmptyAnimation,
     AnimationPlayer as AnimationPlayer,
-    Clock as Clock
-)
\ No newline at end of file
+    Clock as Clock,
+    # -- prefab
+    Label as ASCIILabel
+)
