@@ -2,10 +2,15 @@
 """
 
 __all__ = [
+    # -- standard
     "Vec2",
     "overload",
     "OverloadUnmatched",
     "Node",
+    # -- util
+    "grapheme",
+    # -- core ascii
+    "Node2D",
     "Engine",
     "Camera",
     "Screen",
@@ -16,12 +21,19 @@ __all__ = [
     "Animation",
     "EmptyAnimation",
     "AnimationPlayer",
-    "Clock"
+    "Clock",
+    # -- prefab
+    "Label"
 ]
 
+# -- standard
 from ..math import Vec2
 from ..overload import overload, OverloadUnmatched
-from .node import ASCIINode as Node
+from ..template import Node
+# -- util
+from . import grapheme
+# -- core ascii
+from .node import ASCIINode as Node2D
 from .engine import ASCIIEngine as Engine
 from .camera import ASCIICamera as Camera
 from .surface import ASCIISurface as Surface
@@ -30,9 +42,11 @@ from .image import ASCIIImage as Image
 from .client import ASCIIClient as Client
 from .animation import Frame, Animation, EmptyAnimation, AnimationPlayer
 from .clock import Clock
-# from .constants import * # TODO: find out whether to include this
+# -- prefab
+from .prefab.label import ASCIILabel as Label
 
-# activate ANSI escape codes
+
+# -- activate ANSI escape codes
 import os as _os
 _os.system("")
 # _os.system("cls") # used when developing
