@@ -1,19 +1,17 @@
 from typing_extensions import Self
 from ..math import Vec2
-from ..template import Node
+from ..template import Node2D
 from .types import ASCIISurface
 
 
-class ASCIINode(Node):
+class ASCIINode(Node2D): # a variant of the Node2D
+    __logical__ = False # exists in the "real world"
+
     cell_transparant = " " # type used to indicate that a cell is transparent in `content`
     cell_default = " " # the default look of an empty cell
-    # per instance
-    visible: bool = False
 
-    def __init__(self, owner: Self | None = None, x: int = 0, y: int = 0, z_index: int = 0, force_sort: bool = True) -> None:
-        super().__init__(owner, x, y, z_index)
-        if force_sort:
-            Node._request_sort = True # requests the Engine to sort every frame a new node is created
+    def __init__(self, parent: Self | None = None, x: int = 0, y: int = 0, z_index: int = 0, force_sort: bool = True) -> None:
+        super().__init__(parent, x, y, z_index, force_sort)
         self.content = [] # 2D array
     
     def _render(self, surface: ASCIISurface) -> None:
