@@ -7,9 +7,9 @@ class Engine:
     NOTE: only one Engine instance should exist per script instance
     """
     tps: int = 4
-    is_running = False
+    is_running: bool = False
 
-    def __new__(cls: type[Self]) -> Self:
+    def __new__(cls: type[Self], *args, **kwargs) -> Self:
         instance = object.__new__(cls)
         Node.root = instance
         return instance
